from uuid import UUID

import fastapi

from .schemas import CategoryBaseSchema
from .ctrl import CategoryController
from ..dependencies import get_user_role, get_current_user_scopes


router = fastapi.APIRouter(prefix='/categories', tags=['Category'])
ctrl = CategoryController()


@router.get("")
async def get_categories(
    query: CategoryBaseSchema = fastapi.Depends(),
    current_user: str = fastapi.Depends(get_current_user_scopes)
):
    return await ctrl.get_list(**query.model_dump(exclude_none=True))


@router.get('/{id}')
async def get_category(
    id: UUID,
    current_user: str = fastapi.Depends(get_user_role)
):
    return await ctrl.get(id)


@router.post('')
async def create_category(
    body: CategoryBaseSchema,
    current_user: str = fastapi.Depends(get_user_role)
):
    return await ctrl.create(**body.model_dump(exclude_none=True))


@router.patch('/{id}')
async def update_category(
    id: UUID, body: CategoryBaseSchema,
    current_user: str = fastapi.Depends(get_user_role)
):
    return await ctrl.update(id, **body.model_dump(exclude_none=True))


@router.delete('/{id}')
async def delete_category(
    id: UUID,
    current_user: str = fastapi.Depends(get_user_role)
):
    return await ctrl.delete(id)
