import fastapi as fa
from fastapi.security import SecurityScopes
from fastapi import HTTPException, status

from .user.services import TokenService, oauth2_scheme
from db.repositories import UserRepository, GroupRepository
from db.models import UserRoleEnum


token_service = TokenService()

user_repo = UserRepository()
group_repo = GroupRepository()


async def get_user_role(token: str = fa.Security(oauth2_scheme)):
    token_data = token_service.decode_token(token)

    if token_data.role == UserRoleEnum.system_consumer:
        return await user_repo.get(id=token_data.sub)

    raise HTTPException(
        status_code=status.HTTP_401_UNAUTHORIZED,
        detail="Not authenticated",
        headers={"WWW-Authenticate": "Bearer"},
    )


async def get_current_user_scopes(security_scopes: SecurityScopes, token: str = fa.Depends(oauth2_scheme)):
    if not token:
        raise HTTPException(status_code=401, detail="Invalid authentication credentials")

    token_data = token_service.decode_token(token)

    user = await user_repo.get(id=token_data.sub)

    if not user:
        raise HTTPException(status_code=401, detail="Invalid authentication credentials")

    group_ids = token_data.group
    all_scopes = set()
    for group_id in group_ids:
        group = await group_repo.get(id=group_id)
        scopes = await group.scopes.all()
        all_scopes.update(scopes)

    user_scopes = [scope.name for scope in all_scopes]

    if "read_categories" not in user_scopes:
        raise HTTPException(status_code=403, detail="Not enough permissions")

    return user
