from uuid import UUID

import fastapi

from .schemas import GroupBaseSchema, GroupCreateSchema
from .ctrl import GroupController


router = fastapi.APIRouter(prefix='/groups', tags=['Group'])
ctrl = GroupController()


@router.get('')
async def get_groups(
    query: GroupBaseSchema = fastapi.Depends(),
):
    return await ctrl.get_list(**query.model_dump(exclude_none=True))


@router.get('/{id}')
async def get_group(
    id: UUID,
):
    return await ctrl.get(id)


@router.post('')
async def create_group(
    body: GroupCreateSchema,
):
    return await ctrl.create(**body.model_dump(exclude_none=True))


@router.patch('/{id}')
async def update_group(
    id: UUID, body: GroupBaseSchema,
):
    return await ctrl.update(id, **body.model_dump(exclude_none=True))


@router.delete('/{id}')
async def delete_group(
    id: UUID,
):
    return await ctrl.delete(id)
