from uuid import UUID

from db.repositories import GroupRepository
from .schemas import GroupSchema, GroupGetSchema
from db.models import Scopes


class GroupService:
    group_repository = GroupRepository()

    async def get_group_list(self, **kwargs):
        groups = await self.group_repository.get_list(**kwargs)
        return [GroupSchema.model_validate(group) for group in groups]

    async def get_group(self, id: UUID):
        group = await self.group_repository.get(id)
        return GroupSchema.model_validate(group)

    async def create_group(self, **kwargs):
        scopes_uuids = kwargs.get('scopes', [])
        group = await self.group_repository.create(
            name=kwargs.get('name')
        )

        scopes = await Scopes.filter(id__in=scopes_uuids)
        await group.scopes.add(*scopes)
        group = {
            'id': group.id,
            'name': group.name,
            'scopes': await group.scopes.all().values_list('id', flat=True)
        }
        return GroupGetSchema.model_validate(group)

    async def update_group(self, id: UUID, **kwargs):
        group = await self.group_repository.update(id, **kwargs)
        return GroupSchema.model_validate(group)

    async def delete_group(self, id: UUID):
        return await self.group_repository.delete(id)
