from uuid import UUID

import fastapi

from .schemas import ScopeBaseSchema
from .ctrl import ScopeController


router = fastapi.APIRouter(prefix='/scopes', tags=['Scope'])
ctrl = ScopeController()


@router.get('')
async def get_gscope(
    query: ScopeBaseSchema = fastapi.Depends(),
):
    return await ctrl.get_list(**query.model_dump(exclude_none=True))


@router.get('/{id}')
async def get_scope(
    id: UUID,
):
    return await ctrl.get(id)


@router.post('')
async def create_scope(
    body: ScopeBaseSchema,
):
    return await ctrl.create(**body.model_dump(exclude_none=True))


@router.patch('/{id}')
async def update_scope(
    id: UUID, body: ScopeBaseSchema,
):
    return await ctrl.update(id, **body.model_dump(exclude_none=True))


@router.delete('/{id}')
async def delete_scope(
    id: UUID,
):
    return await ctrl.delete(id)
