from uuid import UUID

import fastapi

from .schemas import StatusBaseSchema
from .ctrl import StatusController
from ..dependencies import get_user_role


router = fastapi.APIRouter(prefix='/statuses', tags=['Status'])
ctrl = StatusController()


@router.get('')
async def get_statuses(
    query: StatusBaseSchema = fastapi.Depends(),
    current_user: str = fastapi.Depends(get_user_role)
):
    return await ctrl.get_list(**query.model_dump(exclude_none=True))


@router.get('/{id}')
async def get_status(
    id: UUID,
    current_user: str = fastapi.Depends(get_user_role)
):
    return await ctrl.get(id)


@router.post('')
async def create_status(
    body: StatusBaseSchema,
    current_user: str = fastapi.Depends(get_user_role)
):
    return await ctrl.create(**body.model_dump(exclude_none=True))


@router.patch('/{id}')
async def update_status(
    id: UUID, body: StatusBaseSchema,
    current_user: str = fastapi.Depends(get_user_role)
):
    return await ctrl.update(id, **body.model_dump(exclude_none=True))


@router.delete('/{id}')
async def delete_status(
    id: UUID,
    current_user: str = fastapi.Depends(get_user_role)
):
    return await ctrl.delete(id)
