from uuid import UUID

import fastapi

from .schemas import TypeBaseSchema
from .ctrl import TypeController
from ..dependencies import get_user_role


router = fastapi.APIRouter(prefix='/types', tags=['Type'])
ctrl = TypeController()


@router.get('')
async def get_types(query: TypeBaseSchema = fastapi.Depends()):
    return await ctrl.get_list(**query.model_dump(exclude_none=True))


@router.get('/{id}')
async def get_type(id: UUID):
    return await ctrl.get(id)


@router.post('')
async def create_type(
    body: TypeBaseSchema,
    current_user: str = fastapi.Depends(get_user_role)
):
    return await ctrl.create(**body.model_dump(exclude_none=True))


@router.patch('/{id}')
async def update_type(
    id: UUID,
    body: TypeBaseSchema,
    current_user: str = fastapi.Depends(get_user_role)
):
    return await ctrl.update(id, **body.model_dump(exclude_none=True))


@router.delete('/{id}')
async def delete_type(
    id: UUID,
    current_user: str = fastapi.Depends(get_user_role)
):
    return await ctrl.delete(id)
