from typing import List
from uuid import UUID
from dataclasses import dataclass, field
from datetime import datetime

from pydantic import BaseModel, ConfigDict
from pydantic import EmailStr

from db.models import UserRoleEnum
from ..group.schemas import GroupIdSchema

class UserBaseSchema(BaseModel):
    username: str | None = None
    password: str | None = None


class UserIdSchema(BaseModel):
    id: UUID

    model_config = ConfigDict(from_attributes=True)


class UserSchema(UserBaseSchema, UserIdSchema):
    pass


class UserListSchema(BaseModel):
    name: str | None = None
    surname: str | None = None
    email: EmailStr | None = None
    role: UserRoleEnum | None = None


class UserGetSchema(BaseModel):
    model_config = ConfigDict(from_attributes=True, use_enum_values=True)
    id: UUID | None = None
    name: str | None = None
    surname: str | None = None
    email: EmailStr | None = None
    role: UserRoleEnum | None = None
    avatar: str | None = None
    group: List[UUID] | None = None


class UserCreateSchema(BaseModel):
    model_config = ConfigDict(use_enum_values=True)
    username: str
    password: str
    name: str
    surname: str
    email: EmailStr
    role: UserRoleEnum
    group: List[UUID] = []


class UserUpdateSchema(BaseModel):
    model_config = ConfigDict(use_enum_values=True)
    name: str | None = None
    surname: str | None = None
    email: EmailStr | None = None
    role: UserRoleEnum | None = None


@dataclass
class TokenData:
    sub: int
    role: str
    group: List[UUID] = field(default_factory=list)
    exp: datetime | None = None


@dataclass
class LoginRequestModel:
    username: str
    password: str
